# google-drive-ti
The Google Drive API allows clients to access resources from Google Drive.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 0.0.2
- Generator version: 7.11.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://google.com](https://google.com)

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import google_drive_ti
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import google_drive_ti
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import google_drive_ti
from google_drive_ti.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://www.googleapis.com/drive/v3
# See configuration.py for a list of all supported configuration parameters.
configuration = google_drive_ti.Configuration(
    host = "https://www.googleapis.com/drive/v3"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

configuration.access_token = os.environ["ACCESS_TOKEN"]

configuration.access_token = os.environ["ACCESS_TOKEN"]


# Enter a context with an instance of the API client
with google_drive_ti.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = google_drive_ti.AboutApi(api_client)
    access_token = 'access_token_example' # str | OAuth access token. (optional)
    alt = json # str | Data format for response. (optional) (default to json)
    param_callback = 'param_callback_example' # str | JSONP (optional)
    fields = 'fields_example' # str | Selector specifying which fields to include in a partial response. (optional)
    key = 'key_example' # str | API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. (optional)
    oauth_token = 'oauth_token_example' # str | OAuth 2.0 token for the current user. (optional)
    pretty_print = True # bool | Returns response with indentations and line breaks. (optional) (default to True)
    quota_user = 'quota_user_example' # str | Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters. (optional)
    upload_protocol = 'upload_protocol_example' # str | Upload protocol for media (e.g. \"raw\", \"multipart\"). (optional)
    upload_type = 'upload_type_example' # str | Legacy upload protocol for media (e.g. \"media\", \"multipart\"). (optional)
    xgafv = 'xgafv_example' # str | V1 error format. (optional)

    try:
        api_response = api_instance.drive_about_get(access_token=access_token, alt=alt, param_callback=param_callback, fields=fields, key=key, oauth_token=oauth_token, pretty_print=pretty_print, quota_user=quota_user, upload_protocol=upload_protocol, upload_type=upload_type, xgafv=xgafv)
        print("The response of AboutApi->drive_about_get:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AboutApi->drive_about_get: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://www.googleapis.com/drive/v3*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AboutApi* | [**drive_about_get**](docs/AboutApi.md#drive_about_get) | **GET** /about | 
*AccessproposalsApi* | [**drive_accessproposals_get**](docs/AccessproposalsApi.md#drive_accessproposals_get) | **GET** /files/{fileId}/accessproposals/{proposalId} | 
*AccessproposalsApi* | [**drive_accessproposals_list**](docs/AccessproposalsApi.md#drive_accessproposals_list) | **GET** /files/{fileId}/accessproposals | 
*AccessproposalsApi* | [**drive_accessproposals_resolve**](docs/AccessproposalsApi.md#drive_accessproposals_resolve) | **POST** /files/{fileId}/accessproposals/{proposalId}:resolve | 
*AppsApi* | [**drive_apps_get**](docs/AppsApi.md#drive_apps_get) | **GET** /apps/{appId} | 
*AppsApi* | [**drive_apps_list**](docs/AppsApi.md#drive_apps_list) | **GET** /apps | 
*ChangesApi* | [**drive_changes_get_start_page_token**](docs/ChangesApi.md#drive_changes_get_start_page_token) | **GET** /changes/startPageToken | 
*ChangesApi* | [**drive_changes_list**](docs/ChangesApi.md#drive_changes_list) | **GET** /changes | 
*ChangesApi* | [**drive_changes_watch**](docs/ChangesApi.md#drive_changes_watch) | **POST** /changes/watch | 
*ChannelsApi* | [**drive_channels_stop**](docs/ChannelsApi.md#drive_channels_stop) | **POST** /channels/stop | 
*CommentsApi* | [**drive_comments_create**](docs/CommentsApi.md#drive_comments_create) | **POST** /files/{fileId}/comments | 
*CommentsApi* | [**drive_comments_delete**](docs/CommentsApi.md#drive_comments_delete) | **DELETE** /files/{fileId}/comments/{commentId} | 
*CommentsApi* | [**drive_comments_get**](docs/CommentsApi.md#drive_comments_get) | **GET** /files/{fileId}/comments/{commentId} | 
*CommentsApi* | [**drive_comments_list**](docs/CommentsApi.md#drive_comments_list) | **GET** /files/{fileId}/comments | 
*CommentsApi* | [**drive_comments_update**](docs/CommentsApi.md#drive_comments_update) | **PATCH** /files/{fileId}/comments/{commentId} | 
*DrivesApi* | [**drive_drives_create**](docs/DrivesApi.md#drive_drives_create) | **POST** /drives | 
*DrivesApi* | [**drive_drives_delete**](docs/DrivesApi.md#drive_drives_delete) | **DELETE** /drives/{driveId} | 
*DrivesApi* | [**drive_drives_get**](docs/DrivesApi.md#drive_drives_get) | **GET** /drives/{driveId} | 
*DrivesApi* | [**drive_drives_hide**](docs/DrivesApi.md#drive_drives_hide) | **POST** /drives/{driveId}/hide | 
*DrivesApi* | [**drive_drives_list**](docs/DrivesApi.md#drive_drives_list) | **GET** /drives | 
*DrivesApi* | [**drive_drives_unhide**](docs/DrivesApi.md#drive_drives_unhide) | **POST** /drives/{driveId}/unhide | 
*DrivesApi* | [**drive_drives_update**](docs/DrivesApi.md#drive_drives_update) | **PATCH** /drives/{driveId} | 
*FilesApi* | [**drive_files_copy**](docs/FilesApi.md#drive_files_copy) | **POST** /files/{fileId}/copy | 
*FilesApi* | [**drive_files_create**](docs/FilesApi.md#drive_files_create) | **POST** /files | 
*FilesApi* | [**drive_files_delete**](docs/FilesApi.md#drive_files_delete) | **DELETE** /files/{fileId} | 
*FilesApi* | [**drive_files_download**](docs/FilesApi.md#drive_files_download) | **POST** /files/{fileId}/download | 
*FilesApi* | [**drive_files_empty_trash**](docs/FilesApi.md#drive_files_empty_trash) | **DELETE** /files/trash | 
*FilesApi* | [**drive_files_export**](docs/FilesApi.md#drive_files_export) | **GET** /files/{fileId}/export | 
*FilesApi* | [**drive_files_generate_ids**](docs/FilesApi.md#drive_files_generate_ids) | **GET** /files/generateIds | 
*FilesApi* | [**drive_files_get**](docs/FilesApi.md#drive_files_get) | **GET** /files/{fileId} | 
*FilesApi* | [**drive_files_list**](docs/FilesApi.md#drive_files_list) | **GET** /files | 
*FilesApi* | [**drive_files_list_labels**](docs/FilesApi.md#drive_files_list_labels) | **GET** /files/{fileId}/listLabels | 
*FilesApi* | [**drive_files_modify_labels**](docs/FilesApi.md#drive_files_modify_labels) | **POST** /files/{fileId}/modifyLabels | 
*FilesApi* | [**drive_files_update**](docs/FilesApi.md#drive_files_update) | **PATCH** /files/{fileId} | 
*FilesApi* | [**drive_files_watch**](docs/FilesApi.md#drive_files_watch) | **POST** /files/{fileId}/watch | 
*OperationApi* | [**drive_operation_cancel**](docs/OperationApi.md#drive_operation_cancel) | **POST** /operation/{name}:cancel | 
*OperationApi* | [**drive_operation_delete**](docs/OperationApi.md#drive_operation_delete) | **DELETE** /operation/{name} | 
*OperationsApi* | [**drive_operations_get**](docs/OperationsApi.md#drive_operations_get) | **GET** /operations/{name} | 
*OperationsApi* | [**drive_operations_list**](docs/OperationsApi.md#drive_operations_list) | **GET** /operations | 
*PermissionsApi* | [**drive_permissions_create**](docs/PermissionsApi.md#drive_permissions_create) | **POST** /files/{fileId}/permissions | 
*PermissionsApi* | [**drive_permissions_delete**](docs/PermissionsApi.md#drive_permissions_delete) | **DELETE** /files/{fileId}/permissions/{permissionId} | 
*PermissionsApi* | [**drive_permissions_get**](docs/PermissionsApi.md#drive_permissions_get) | **GET** /files/{fileId}/permissions/{permissionId} | 
*PermissionsApi* | [**drive_permissions_list**](docs/PermissionsApi.md#drive_permissions_list) | **GET** /files/{fileId}/permissions | 
*PermissionsApi* | [**drive_permissions_update**](docs/PermissionsApi.md#drive_permissions_update) | **PATCH** /files/{fileId}/permissions/{permissionId} | 
*RepliesApi* | [**drive_replies_create**](docs/RepliesApi.md#drive_replies_create) | **POST** /files/{fileId}/comments/{commentId}/replies | 
*RepliesApi* | [**drive_replies_delete**](docs/RepliesApi.md#drive_replies_delete) | **DELETE** /files/{fileId}/comments/{commentId}/replies/{replyId} | 
*RepliesApi* | [**drive_replies_get**](docs/RepliesApi.md#drive_replies_get) | **GET** /files/{fileId}/comments/{commentId}/replies/{replyId} | 
*RepliesApi* | [**drive_replies_list**](docs/RepliesApi.md#drive_replies_list) | **GET** /files/{fileId}/comments/{commentId}/replies | 
*RepliesApi* | [**drive_replies_update**](docs/RepliesApi.md#drive_replies_update) | **PATCH** /files/{fileId}/comments/{commentId}/replies/{replyId} | 
*RevisionsApi* | [**drive_revisions_delete**](docs/RevisionsApi.md#drive_revisions_delete) | **DELETE** /files/{fileId}/revisions/{revisionId} | 
*RevisionsApi* | [**drive_revisions_get**](docs/RevisionsApi.md#drive_revisions_get) | **GET** /files/{fileId}/revisions/{revisionId} | 
*RevisionsApi* | [**drive_revisions_list**](docs/RevisionsApi.md#drive_revisions_list) | **GET** /files/{fileId}/revisions | 
*RevisionsApi* | [**drive_revisions_update**](docs/RevisionsApi.md#drive_revisions_update) | **PATCH** /files/{fileId}/revisions/{revisionId} | 
*TeamdrivesApi* | [**drive_teamdrives_create**](docs/TeamdrivesApi.md#drive_teamdrives_create) | **POST** /teamdrives | 
*TeamdrivesApi* | [**drive_teamdrives_delete**](docs/TeamdrivesApi.md#drive_teamdrives_delete) | **DELETE** /teamdrives/{teamDriveId} | 
*TeamdrivesApi* | [**drive_teamdrives_get**](docs/TeamdrivesApi.md#drive_teamdrives_get) | **GET** /teamdrives/{teamDriveId} | 
*TeamdrivesApi* | [**drive_teamdrives_list**](docs/TeamdrivesApi.md#drive_teamdrives_list) | **GET** /teamdrives | 
*TeamdrivesApi* | [**drive_teamdrives_update**](docs/TeamdrivesApi.md#drive_teamdrives_update) | **PATCH** /teamdrives/{teamDriveId} | 


## Documentation For Models

 - [About](docs/About.md)
 - [AboutDriveThemesInner](docs/AboutDriveThemesInner.md)
 - [AboutStorageQuota](docs/AboutStorageQuota.md)
 - [AboutTeamDriveThemesInner](docs/AboutTeamDriveThemesInner.md)
 - [AccessProposal](docs/AccessProposal.md)
 - [AccessProposalRoleAndView](docs/AccessProposalRoleAndView.md)
 - [App](docs/App.md)
 - [AppIcons](docs/AppIcons.md)
 - [AppList](docs/AppList.md)
 - [Change](docs/Change.md)
 - [ChangeList](docs/ChangeList.md)
 - [Channel](docs/Channel.md)
 - [Comment](docs/Comment.md)
 - [CommentList](docs/CommentList.md)
 - [CommentQuotedFileContent](docs/CommentQuotedFileContent.md)
 - [ContentRestriction](docs/ContentRestriction.md)
 - [Drive](docs/Drive.md)
 - [DriveBackgroundImageFile](docs/DriveBackgroundImageFile.md)
 - [DriveCapabilities](docs/DriveCapabilities.md)
 - [DriveList](docs/DriveList.md)
 - [DriveRestrictions](docs/DriveRestrictions.md)
 - [File](docs/File.md)
 - [FileCapabilities](docs/FileCapabilities.md)
 - [FileContentHints](docs/FileContentHints.md)
 - [FileContentHintsThumbnail](docs/FileContentHintsThumbnail.md)
 - [FileImageMediaMetadata](docs/FileImageMediaMetadata.md)
 - [FileImageMediaMetadataLocation](docs/FileImageMediaMetadataLocation.md)
 - [FileLabelInfo](docs/FileLabelInfo.md)
 - [FileLinkShareMetadata](docs/FileLinkShareMetadata.md)
 - [FileList](docs/FileList.md)
 - [FileShortcutDetails](docs/FileShortcutDetails.md)
 - [FileVideoMediaMetadata](docs/FileVideoMediaMetadata.md)
 - [GeneratedIds](docs/GeneratedIds.md)
 - [Label](docs/Label.md)
 - [LabelField](docs/LabelField.md)
 - [LabelFieldModification](docs/LabelFieldModification.md)
 - [LabelList](docs/LabelList.md)
 - [LabelModification](docs/LabelModification.md)
 - [ListAccessProposalsResponse](docs/ListAccessProposalsResponse.md)
 - [ListOperationsResponse](docs/ListOperationsResponse.md)
 - [ModifyLabelsRequest](docs/ModifyLabelsRequest.md)
 - [ModifyLabelsResponse](docs/ModifyLabelsResponse.md)
 - [Operation](docs/Operation.md)
 - [Permission](docs/Permission.md)
 - [PermissionList](docs/PermissionList.md)
 - [PermissionPermissionDetailsInner](docs/PermissionPermissionDetailsInner.md)
 - [PermissionTeamDrivePermissionDetailsInner](docs/PermissionTeamDrivePermissionDetailsInner.md)
 - [Reply](docs/Reply.md)
 - [ReplyList](docs/ReplyList.md)
 - [ResolveAccessProposalRequest](docs/ResolveAccessProposalRequest.md)
 - [Revision](docs/Revision.md)
 - [RevisionList](docs/RevisionList.md)
 - [StartPageToken](docs/StartPageToken.md)
 - [Status](docs/Status.md)
 - [TeamDrive](docs/TeamDrive.md)
 - [TeamDriveBackgroundImageFile](docs/TeamDriveBackgroundImageFile.md)
 - [TeamDriveCapabilities](docs/TeamDriveCapabilities.md)
 - [TeamDriveList](docs/TeamDriveList.md)
 - [TeamDriveRestrictions](docs/TeamDriveRestrictions.md)
 - [User](docs/User.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="Oauth2"></a>
### Oauth2

- **Type**: OAuth
- **Flow**: implicit
- **Authorization URL**: https://accounts.google.com/o/oauth2/auth
- **Scopes**: 
 - **https://www.googleapis.com/auth/drive**: See, edit, create, and delete all of your Google Drive files
 - **https://www.googleapis.com/auth/drive.appdata**: See, create, and delete its own configuration data in your Google Drive
 - **https://www.googleapis.com/auth/drive.apps.readonly**: View your Google Drive apps
 - **https://www.googleapis.com/auth/drive.file**: See, edit, create, and delete only the specific Google Drive files you use with this app
 - **https://www.googleapis.com/auth/drive.meet.readonly**: See and download your Google Drive files that were created or edited by Google Meet.
 - **https://www.googleapis.com/auth/drive.metadata**: View and manage metadata of files in your Google Drive
 - **https://www.googleapis.com/auth/drive.metadata.readonly**: See information about your Google Drive files
 - **https://www.googleapis.com/auth/drive.photos.readonly**: View the photos, videos and albums in your Google Photos
 - **https://www.googleapis.com/auth/drive.readonly**: See and download all your Google Drive files
 - **https://www.googleapis.com/auth/drive.scripts**: Modify your Google Apps Script scripts' behavior

<a id="Oauth2c"></a>
### Oauth2c

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://accounts.google.com/o/oauth2/auth
- **Scopes**: 
 - **https://www.googleapis.com/auth/drive**: See, edit, create, and delete all of your Google Drive files
 - **https://www.googleapis.com/auth/drive.appdata**: See, create, and delete its own configuration data in your Google Drive
 - **https://www.googleapis.com/auth/drive.apps.readonly**: View your Google Drive apps
 - **https://www.googleapis.com/auth/drive.file**: See, edit, create, and delete only the specific Google Drive files you use with this app
 - **https://www.googleapis.com/auth/drive.meet.readonly**: See and download your Google Drive files that were created or edited by Google Meet.
 - **https://www.googleapis.com/auth/drive.metadata**: View and manage metadata of files in your Google Drive
 - **https://www.googleapis.com/auth/drive.metadata.readonly**: See information about your Google Drive files
 - **https://www.googleapis.com/auth/drive.photos.readonly**: View the photos, videos and albums in your Google Photos
 - **https://www.googleapis.com/auth/drive.readonly**: See and download all your Google Drive files
 - **https://www.googleapis.com/auth/drive.scripts**: Modify your Google Apps Script scripts' behavior


## Author




